``pants.stream``
****************

.. automodule:: pants.stream


``Stream``
==========

.. autoclass:: Stream
    :members: connect, close, end, write, write_file, flush, on_read, on_write, on_connect, on_connect_error, on_close


``StreamServer``
================

.. autoclass:: StreamServer
    :members: listen, close, on_listen, on_accept, on_close
